@@ -10,6 +10,11 @@
 import os
 import sys
 import shutil
+import plotly.io as pio
+from plotly.io._sg_scraper import plotly_sg_scraper
+from sphinx_gallery.sorting import FileNameSortKey
+
+pio.renderers.default = "sphinx_gallery"
 
 # -- Path setup --------------------------------------------------------------
 
@@ -50,7 +55,7 @@ try:
         # This is a rudimentary parse_version to avoid external dependencies
         args = args[1:]
 
-    apidoc.main(args)
+    # apidoc.main(args)
 except Exception as e:
     print("Running `sphinx-apidoc` failed!\n{}".format(e))
 
@@ -63,6 +68,7 @@ except Exception as e:
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     "sphinx.ext.autodoc",
+    "sphinx.ext.autosectionlabel",
     "sphinx.ext.intersphinx",
     "sphinx.ext.todo",
     "sphinx.ext.autosummary",
@@ -72,17 +78,42 @@ extensions = [
     "sphinx.ext.ifconfig",
     "sphinx.ext.mathjax",
     "sphinx.ext.napoleon",
+    "sphinx_plotly_directive",
     "sphinx_rtd_theme",
-    "m2r2"
+    "m2r2",
+    "sphinx_gallery.gen_gallery",
+    "sphinxcontrib.mermaid",
 ]
 
+plotly_html_show_source_link = False
+plotly_html_show_formats = False
+plotly_pre_code = "import elli"
+
+
+image_scrapers = (
+    "matplotlib",
+    plotly_sg_scraper,
+)
+
+sphinx_gallery_conf = {
+    "examples_dirs": "../examples/gallery",  # path to your example scripts
+    "gallery_dirs": "auto_examples",  # path to where to save gallery generated output
+    "capture_repr": ("_repr_html_", "__repr__"),
+    "image_scrapers": image_scrapers,
+    "remove_config_comments": True,
+    "download_all_examples": False,
+    "show_signature": False,
+    "first_notebook_cell": None,
+    "within_subsection_order": FileNameSortKey,
+}
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
 
 # The suffix of source filenames.
-source_suffix = [".rst", '.md']
+source_suffix = [".rst", ".md"]
 
-autoclass_content = 'both'
+autoclass_content = "both"
 
 # The encoding of source files.
 # source_encoding = 'utf-8-sig'
@@ -164,10 +195,7 @@ html_theme = "sphinx_rtd_theme"
 # Theme options are theme-specific and customize the look and feel of a theme
 # further.  For a list of options available for each theme, see the
 # documentation.
-html_theme_options = {
-    "sidebar_width": "300px",
-    "page_width": "1200px"
-}
+html_theme_options = {"sidebar_width": "300px", "page_width": "1200px"}
 
 # Add any paths that contain custom themes here, relative to this directory.
 # html_theme_path = []
@@ -181,7 +209,7 @@ html_theme_options = {
 
 # The name of an image file (relative to this directory) to place at the top
 # of the sidebar.
-# html_logo = ""
+html_logo = "../logo/logo_bw.svg"
 
 # The name of an image file (within the static path) to use as favicon of the
 # docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
@@ -192,6 +220,7 @@ html_theme_options = {
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ["_static"]
+html_css_files = ["style.css"]
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
