@@ -1,13 +1,14 @@
 # Encoding: utf-8
 import sys
 
+from . import database as db
+from .database.materials_db import AIR
 from .dispersions import *
 from .dispersions.base_dispersion import *
 from .experiment import Experiment
 from .importer.nexus import *
 from .importer.spectraray import *
 from .materials import *
-from .materials_db import *
 from .result import Result, ResultList
 from .solver2x2 import Solver2x2
 from .solver4x4 import *
