@@ -1,5 +1,6 @@
 # Encoding: utf-8
 from .cauchy import Cauchy
+from .cauchy_custom import CauchyCustomExponent
 from .constant_refractive_index import ConstantRefractiveIndex
 from .drude_energy import DrudeEnergy
 from .drude_resistivity import DrudeResistivity
@@ -8,9 +9,12 @@ from .gaussian import Gaussian
 from .lorentz_energy import LorentzEnergy
 from .lorentz_lambda import LorentzLambda
 from .poles import Poles
+from .polynomial import Polynomial
 from .sellmeier import Sellmeier
+from .sellmeier_custom import SellmeierCustomExponent
 from .table_epsilon import TableEpsilon
 from .table_index import Table
 from .table_spectraray import TableSpectraRay
 from .tanguy import Tanguy
 from .tauc_lorentz import TaucLorentz
+from .cody_lorentz import CodyLorentz
