@@ -21,7 +21,7 @@ class Cauchy(Dispersion):
 
     Output:
         .. math::
-            \varepsilon^2(\lambda) =
+            \varepsilon^{1/2}(\lambda) =
             \boldsymbol{n_0} + 100  \boldsymbol{n_1}/\lambda^2 + 10^7 \boldsymbol{n_2}/\lambda^4
             + i (\boldsymbol{k_0} + 100 \boldsymbol{k_1}/\lambda^2
             + 10^7 \boldsymbol{k_2}/\lambda^4)
