@@ -2,15 +2,40 @@
 # Encoding: utf-8
 from abc import ABC, abstractmethod
 
+import pandas as pd
+
 try:
+    from lmfit import Parameters
     from ipywidgets import widgets
 except ImportError as e:
-    raise ImportError("This module requires ipywidgets to work properly.") from e
-from lmfit import Parameters
-import pandas as pd
+    raise ImportError(
+        "This module requires lmfit and ipywidgets to work properly.\n"
+        "Try installing this package with the additional fitting requirement, "
+        "i.e. pip install pyElli[fitting]"
+    ) from e
+
 from .params_hist import ParamsHist
 
 
+def is_in_notebook() -> bool:
+    """Checks whether the current shell is in a jupyter notebook.
+
+    Returns:
+        bool: True if the shell is in jupyter, False otherwise.
+    """
+    try:
+        # pylint: disable=import-outside-toplevel
+        from IPython import get_ipython
+
+        if "IPKernelApp" not in get_ipython().config:
+            return False
+    except ImportError:
+        return False
+    except AttributeError:
+        return False
+    return True
+
+
 class FitDecorator(ABC):
     """The abstract base class for fitting decorators.
     Providing features for fit, undo and redo buttons."""
@@ -42,14 +67,13 @@ class FitDecorator(ABC):
         Returns:
             pd.DataFrame: The model results
         """
-        ...
 
     def to_csv(
         self,
+        *args,
         fname: str,
         params: Parameters = None,
         append_exp_data: bool = False,
-        *args,
         **kwargs
     ) -> None:
         """Saves the current model to csv. This is just a wrapper to
@@ -80,7 +104,6 @@ class FitDecorator(ABC):
         Returns:
             Result: The fitting result
         """
-        ...
 
     @abstractmethod
     def update_selection(self, change: dict = None) -> None:
@@ -89,7 +112,6 @@ class FitDecorator(ABC):
         Args:
             change (dict, optional): A dictionary containing the ipywidgets change event
         """
-        ...
 
     def set_vary_param(self, change: dict) -> None:
         self.initial_params[change.owner.description_tooltip].vary = change.new
@@ -111,7 +133,7 @@ class FitDecorator(ABC):
         self.update_selection()
 
     def re_undo_button_clicked(self, button: widgets.Button) -> None:
-        """Redo or undo an operation on the paramters history object
+        """Redo or undo an operation on the parameters history object
 
         Args:
             button (widgets.Button):
