@@ -1,24 +1,28 @@
 """Decorator functions for convenient fitting"""
 # Encoding: utf-8
-from typing import Callable
 from sys import float_info
+from typing import Callable
+
 import numpy as np
 import numpy.typing as npt
 import pandas as pd
 
 try:
+    from lmfit import Parameters, minimize
     import plotly.graph_objects as go
-    from ipywidgets import widgets
     from IPython.display import display
+    from ipywidgets import widgets
 except ImportError as e:
     raise ImportError(
-        "This module requires plotly, ipywidgets and ipython to be installed."
+        "This module requires lmfit, plotly, ipywidgets and ipython to be installed.\n"
+        "Try installing this package with the additional fitting requirement, "
+        "i.e. pip install pyElli[fitting]"
     ) from e
-from lmfit import minimize, Parameters
+
 from ..result import Result
 from ..utils import calc_pseudo_diel, calc_rho
+from .decorator import FitDecorator, is_in_notebook
 from .params_hist import ParamsHist
-from .decorator import FitDecorator
 
 
 class FitRho(FitDecorator):
@@ -201,19 +205,22 @@ class FitRho(FitDecorator):
             widgets.HBox([v, w])
             for v, w in zip(list(self.param_widgets.values()), checkboxes)
         ]
-        display(
-            widgets.VBox(
-                [
-                    widgets.HBox(
-                        combo_widget + button_list,
-                        layout=widgets.Layout(
-                            width="100%", display="inline-flex", flex_flow="row wrap"
+        if is_in_notebook():
+            display(
+                widgets.VBox(
+                    [
+                        widgets.HBox(
+                            combo_widget + button_list,
+                            layout=widgets.Layout(
+                                width="100%",
+                                display="inline-flex",
+                                flex_flow="row wrap",
+                            ),
                         ),
-                    ),
-                    self.fig,
-                ]
+                        self.fig,
+                    ]
+                )
             )
-        )
 
     def fit_function(
         self,
