@@ -1,144 +1,92 @@
 # Encoding: utf-8
 from abc import ABC, abstractmethod
+
 import numpy as np
 import numpy.typing as npt
+import scipy.constants as sc
 from numpy.lib.scimath import sqrt
 from scipy.linalg import expm as scipy_expm
-import scipy.constants as sc
-
-try:
-    import tensorflow as tf
-except ImportError:
-    pass
-
-try:
-    import torch
-except ImportError:
-    pass
 
 from .materials import IsotropicMaterial
-from .solver import Solver
 from .result import Result
+from .solver import Solver
 
 
 class Propagator(ABC):
-    """Propagator abstract base class.
-    """
+    """Propagator abstract base class."""
+
     @abstractmethod
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
+    def calculate_propagation(
+        self, delta: npt.NDArray, thickness: float, lbda: npt.ArrayLike
+    ) -> npt.NDArray:
         """Calculates propagation for a given Delta matrix and layer thickness.
 
         Args:
             delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
+            thickness (float): Thickness of layer (nm)
             lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
 
         Returns:
             npt.NDArray: Propagator for the given layer
         """
-        pass
 
 
 class PropagatorLinear(Propagator):
-    """Propagator class using a simple linear approximation of the matrix exponential.
-    """
+    """Propagator class using a simple linear approximation of the matrix exponential."""
 
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
+    def calculate_propagation(
+        self, delta: npt.NDArray, thickness: float, lbda: npt.ArrayLike
+    ) -> npt.NDArray:
         """Calculates propagation for a given Delta matrix and layer thickness with a linear approximation of the matrix exponential.
 
         Args:
             delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
+            thickness (float): Thickness of layer (nm)
             lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
 
         Returns:
             npt.NDArray: Propagator for the given layer
         """
-        p_hs_lin = np.identity(4) + 1j * h * \
-            np.einsum('nij,n->nij', delta, 2 * sc.pi / lbda)
+        p_hs_lin = np.identity(4) + 1j * thickness * np.einsum(
+            "nij,n->nij", delta, 2 * sc.pi / lbda
+        )
         return p_hs_lin
 
 
-class PropagatorExpmScipy(Propagator):
-    """Propagator class using the Padé approximation of the matrix exponential.
-    """
+class PropagatorExpm(Propagator):
+    """Propagator class using the Padé approximation of the matrix exponential."""
 
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
+    def calculate_propagation(
+        self, delta: npt.NDArray, thickness: float, lbda: npt.ArrayLike
+    ) -> npt.NDArray:
         """Calculates propagation for a given Delta matrix and layer thickness with the Padé approximation of the matrix exponential.
 
         Args:
             delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
+            thickness (float): Thickness of layer (nm)
             lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
 
         Returns:
             npt.NDArray: Propagator for the given layer
         """
-        mats = 1j * h * np.einsum('nij,n->nij', delta, 2 * sc.pi / lbda)
+        mats = 1j * thickness * np.einsum("nij,n->nij", delta, 2 * sc.pi / lbda)
 
-        p_hs_pade = np.asarray([scipy_expm(mat) for mat in mats])
+        propagator = np.asarray([scipy_expm(mat) for mat in mats])
 
-        return p_hs_pade
-
-
-class PropagatorExpmTorch(Propagator):
-    """Propagator class using a vectorized polynomial approximation of the matrix exponential.
-    """
-
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
-        """Calculates propagation for a given Delta matrix and layer thickness with the polynomial approximation of the matrix exponential.
-
-        Args:
-            delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
-            lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
-
-        Returns:
-            npt.NDArray: Propagator for the given layer
-        """
-        mats = 1j * h * np.einsum('nij,n->nij', delta, 2 * sc.pi / lbda)
-
-        t = torch.from_numpy(mats)
-        texp = torch.matrix_exp(t)
-        p_hs_taylor = np.asarray(texp.numpy(), dtype=np.complex128)
-
-        return p_hs_taylor
-
-
-class PropagatorExpmTF(Propagator):
-    """Propagator class using a vectorized Padé approximation of the matrix exponential
-    """
-
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
-        """Calculates propagation for a given Delta matrix and layer thickness with the Padé approximation of the matrix exponential.
-
-        Args:
-            delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
-            lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
-
-        Returns:
-            npt.NDArray: Propagator for the given layer
-        """
-        mats = 1j * h * np.einsum('nij,n->nij', delta, 2 * sc.pi / lbda)
-
-        t = tf.convert_to_tensor(np.asarray(mats, dtype=np.complex64))
-        texp = tf.linalg.expm(t)
-        p_hs_pade = np.array(texp, dtype=np.complex128)
-
-        return p_hs_pade
+        return propagator
 
 
 class PropagatorEig(Propagator):
-    """Propagator class using the eigenvalue decomposition method.
-    """
+    """Propagator class using the eigenvalue decomposition method."""
 
-    def calculate_propagation(self, delta: npt.NDArray, h: float, lbda: npt.ArrayLike) -> npt.NDArray:
+    def calculate_propagation(
+        self, delta: npt.NDArray, thickness: float, lbda: npt.ArrayLike
+    ) -> npt.NDArray:
         """Calculates propagation for a given Delta matrix and layer thickness with eigenvalue decomposition.
 
         Args:
             delta (npt.NDArray): Delta Matrix
-            h (float): Thickness of layer (nm)
+            thickness (float): Thickness of layer (nm)
             lbda (npt.ArrayLike): Wavelengths to evaluate (nm)
 
         Returns:
@@ -146,28 +94,25 @@ class PropagatorEig(Propagator):
         """
         q, w = np.linalg.eig(delta)
 
-        # Sort according to z propagation direction, highest Re(q) first
-        # if Re(q) is zero, sort by Im(q)
-        i = np.where(np.isclose(q.real, 0), np.argsort(-np.imag(q)),
-                     np.argsort(-np.real(q)))
+        # Sort according to z propagation direction, by Re(q) first, then Im(q)
+        i = np.lexsort((-np.real(q), -np.imag(q)))
 
         q = np.take_along_axis(q, i, axis=-1)
         w = np.take_along_axis(w, i[:, np.newaxis, :], axis=-1)
 
-        wi = np.linalg.inv(w)
+        w_i = np.linalg.inv(w)
 
-        q = np.exp(q * 2j * h * sc.pi / lbda[:, None])
+        q = np.exp(q * 2j * thickness * sc.pi / lbda[:, None])
 
         p = np.zeros((lbda.shape[0], 4, 4), dtype=np.complex128)
         for i in range(4):
             p[:, i, i] = q[:, i]
 
-        return w @ p @ wi
+        return w @ p @ w_i
 
 
 class Solver4x4(Solver):
-    """Solver class to evaluate Experiment objects. Based on Berreman's 4x4 method.
-    """
+    """Solver class to evaluate Experiment objects. Based on Berreman's 4x4 method."""
 
     @staticmethod
     def build_delta_matrix(k_x: npt.ArrayLike, eps: npt.NDArray) -> npt.NDArray:
@@ -181,23 +126,39 @@ class Solver4x4(Solver):
             npt.NDArray: Delta 4x4 matrix: infinitesimal propagation matrix
         """
         if np.shape(k_x) == ():
-            i = 1
+            length = 1
         else:
-            i = np.shape(k_x)[0]
+            length = np.shape(k_x)[0]
 
-        zeros = np.tile(0, i)
-        ones = np.tile(1, i)
+        zeros = np.tile(0, length)
+        ones = np.tile(1, length)
 
         delta = np.array(
-            [[-k_x * eps[:, 2, 0] / eps[:, 2, 2], -k_x * eps[:, 2, 1] / eps[:, 2, 2],
-              zeros, ones - k_x ** 2 / eps[:, 2, 2]],
-             [zeros, zeros, -ones, zeros],
-             [eps[:, 1, 2] * eps[:, 2, 0] / eps[:, 2, 2] - eps[:, 1, 0],
-              k_x ** 2 - eps[:, 1, 1] + eps[:, 1, 2] * eps[:, 2, 1] / eps[:, 2, 2],
-              zeros, k_x * eps[:, 1, 2] / eps[:, 2, 2]],
-             [eps[:, 0, 0] - eps[:, 0, 2] * eps[:, 2, 0] / eps[:, 2, 2],
-              eps[:, 0, 1] - eps[:, 0, 2] * eps[:, 2, 1] / eps[:, 2, 2],
-              zeros, -k_x * eps[:, 0, 2] / eps[:, 2, 2]]], dtype=np.complex128)
+            [
+                [
+                    -k_x * eps[:, 2, 0] / eps[:, 2, 2],
+                    -k_x * eps[:, 2, 1] / eps[:, 2, 2],
+                    zeros,
+                    ones - k_x**2 / eps[:, 2, 2],
+                ],
+                [zeros, zeros, -ones, zeros],
+                [
+                    eps[:, 1, 2] * eps[:, 2, 0] / eps[:, 2, 2] - eps[:, 1, 0],
+                    k_x**2
+                    - eps[:, 1, 1]
+                    + eps[:, 1, 2] * eps[:, 2, 1] / eps[:, 2, 2],
+                    zeros,
+                    k_x * eps[:, 1, 2] / eps[:, 2, 2],
+                ],
+                [
+                    eps[:, 0, 0] - eps[:, 0, 2] * eps[:, 2, 0] / eps[:, 2, 2],
+                    eps[:, 0, 1] - eps[:, 0, 2] * eps[:, 2, 1] / eps[:, 2, 2],
+                    zeros,
+                    -k_x * eps[:, 0, 2] / eps[:, 2, 2],
+                ],
+            ],
+            dtype=np.complex128,
+        )
         delta = np.moveaxis(delta, 2, 0)
         return delta
 
@@ -218,13 +179,11 @@ class Solver4x4(Solver):
         """
         q, p = np.linalg.eig(delta)
 
-        # Sort according to z propagation direction, highest Re(q) first
-        # if Re(q) is zero, sort by Im(q)
-        i = np.where(np.isclose(q.real, 0), np.argsort(-np.imag(q)),
-                     np.argsort(-np.real(q)))
+        # Sort according to z propagation direction, by Re(q) first, then Im(q)
+        idx = np.lexsort((-np.real(q), -np.imag(q)))
 
-        q = np.take_along_axis(q, i, axis=-1)
-        p = np.take_along_axis(p, i[:, np.newaxis, :], axis=-1)
+        q = np.take_along_axis(q, idx, axis=-1)
+        p = np.take_along_axis(p, idx[:, np.newaxis, :], axis=-1)
         # Result should be (+,+,-,-)
 
         # For each direction, sort according to Ey component, highest Ey first
@@ -245,7 +204,7 @@ class Solver4x4(Solver):
 
         ne = np.abs(e)
         c = np.ones_like(e)
-        i = (ne != 0.0)
+        i = ne != 0.0
         c[i] = e[i] / ne[i]
 
         p = p * c[:, np.newaxis, :]
@@ -261,9 +220,9 @@ class Solver4x4(Solver):
         return p
 
     @staticmethod
-    def transition_matrix_iso_halfspace(k_x: npt.ArrayLike,
-                                        epsilon: npt.ArrayLike,
-                                        inv: bool = False) -> npt.NDArray:
+    def transition_matrix_iso_halfspace(
+        k_x: npt.ArrayLike, epsilon: npt.ArrayLike, inv: bool = False
+    ) -> npt.NDArray:
         """Returns transition incident or exit matrix L for isotropic half-spaces.
 
         Args:
@@ -278,27 +237,37 @@ class Solver4x4(Solver):
         sin_phi = k_x / n_x
         cos_phi = sqrt(1 - sin_phi**2)
 
-        i = np.shape(k_x)[0]
-        zeros = np.tile(0, i)
-        ones = np.tile(1, i)
+        length = np.shape(k_x)[0]
+        zeros = np.tile(0, length)
+        ones = np.tile(1, length)
 
         if inv:
-            sp_to_xy = np.array([[zeros,           ones,   -ones / cos_phi / n_x, zeros],
-                                 [zeros,           ones,   ones / cos_phi / n_x,  zeros],
-                                 [ones / cos_phi,  zeros,  zeros,                 ones / n_x],
-                                 [-ones / cos_phi, zeros,  zeros,                 ones / n_x]],
-                                dtype=np.complex128)
+            sp_to_xy = np.array(
+                [
+                    [zeros, ones, -ones / cos_phi / n_x, zeros],
+                    [zeros, ones, ones / cos_phi / n_x, zeros],
+                    [ones / cos_phi, zeros, zeros, ones / n_x],
+                    [-ones / cos_phi, zeros, zeros, ones / n_x],
+                ],
+                dtype=np.complex128,
+            )
             return np.moveaxis(0.5 * sp_to_xy, 2, 0)
 
-        sp_to_xy = np.array([[zeros,          zeros,          cos_phi, -cos_phi],
-                             [ones,           ones,           zeros,   zeros],
-                             [-n_x * cos_phi, n_x * cos_phi,  zeros,   zeros],
-                             [zeros,          zeros,          n_x,     n_x]],
-                            dtype=np.complex128)
+        sp_to_xy = np.array(
+            [
+                [zeros, zeros, cos_phi, -cos_phi],
+                [ones, ones, zeros, zeros],
+                [-n_x * cos_phi, n_x * cos_phi, zeros, zeros],
+                [zeros, zeros, n_x, n_x],
+            ],
+            dtype=np.complex128,
+        )
         return np.moveaxis(sp_to_xy, 2, 0)
 
     @staticmethod
-    def get_k_z(material: "Material", lbda: npt.ArrayLike, k_x: npt.ArrayLike) -> npt.NDArray:
+    def get_k_z(
+        material: "Material", lbda: npt.ArrayLike, k_x: npt.ArrayLike
+    ) -> npt.NDArray:
         """Calculates Kz in a material
 
         Args:
@@ -310,10 +279,12 @@ class Solver4x4(Solver):
             npt.NDArray: value of Kz in the material
         """
         nx = material.get_refractive_index(lbda)[:, 0, 0]
-        k_z2 = nx ** 2 - k_x ** 2
+        k_z2 = nx**2 - k_x**2
         return sqrt(k_z2)
 
-    def __init__(self, experiment: "Experiment", propagator: Propagator = PropagatorExpmScipy()) -> None:
+    def __init__(
+        self, experiment: "Experiment", propagator: Propagator = PropagatorExpm()
+    ) -> None:
         super().__init__(experiment)
         self.propagator = propagator
 
@@ -330,34 +301,39 @@ class Solver4x4(Solver):
         layers = reversed(self.permittivity_profile[1:-1])
 
         if isinstance(self.structure.back_material, IsotropicMaterial):
-            t = self.transition_matrix_iso_halfspace(k_x, self.permittivity_profile[-1][1])
+            m_t = self.transition_matrix_iso_halfspace(
+                k_x, self.permittivity_profile[-1][1]
+            )
         else:
-            t = self.transition_matrix_halfspace(
-                self.build_delta_matrix(k_x, self.permittivity_profile[-1][1]))
+            m_t = self.transition_matrix_halfspace(
+                self.build_delta_matrix(k_x, self.permittivity_profile[-1][1])
+            )
 
-        for d, epsilon in layers:
-            p = self.propagator.calculate_propagation(
-                self.build_delta_matrix(k_x, epsilon), -d, self.lbda)
-            t = p @ t
+        for thickness, epsilon in layers:
+            m_p = self.propagator.calculate_propagation(
+                self.build_delta_matrix(k_x, epsilon), -thickness, self.lbda
+            )
+            m_t = m_p @ m_t
 
-        lf = self.transition_matrix_iso_halfspace(
-            k_x, self.permittivity_profile[0][1], inv=True)
-        t = lf @ t
+        m_lf = self.transition_matrix_iso_halfspace(
+            k_x, self.permittivity_profile[0][1], inv=True
+        )
+        m_t = m_lf @ m_t
 
-        # Extraction of t_it out of t. "2::-2" means integers {2,0}.
-        t_it = t[:, 2::-2, 2::-2]
+        # Extraction of t_it out of m_t. "2::-2" means integers {2,0}.
+        t_it = m_t[:, 2::-2, 2::-2]
         # Calculate the inverse and make sure it is a matrix.
         t_ti = np.linalg.inv(t_it)
 
-        # Extraction of t_rt out of t. "3::-2" means integers {3,1}.
-        t_rt = t[:, 3::-2, 2::-2]
+        # Extraction of t_rt out of m_t. "3::-2" means integers {3,1}.
+        t_rt = m_t[:, 3::-2, 2::-2]
 
         # Then we have t_ri = t_rt * t_ti
         t_ri = t_rt @ t_ti
 
         jones_matrix_t = t_ti
         jones_matrix_r = t_ri
-        
+
         # The power transmission coefficient is the ratio of the 'z' components
         # of the Poynting vector:       t = P_t_z / P_i_z
         # For isotropic media, we have: t = kb'/kf' |t_bf|^2
@@ -367,6 +343,8 @@ class Solver4x4(Solver):
             k_z_f = self.get_k_z(self.structure.front_material, self.lbda, k_x)
             k_z_b = self.get_k_z(self.structure.back_material, self.lbda, k_x)
             power_correction = k_z_b.real / k_z_f.real
-            return Result(self.experiment, jones_matrix_r, jones_matrix_t, power_correction)
+            return Result(
+                self.experiment, jones_matrix_r, jones_matrix_t, power_correction
+            )
 
         return Result(self.experiment, jones_matrix_r, jones_matrix_t)
