@@ -1,9 +1,11 @@
 """Tests for a TiO2/SiO2/Si reference layer"""
 from __future__ import unicode_literals
-from distutils import dir_util
+
 import os
+from distutils import dir_util
+
+import elli
 from pytest import fixture
-from elli.nexus import read_psi_delta, read_rho
 
 
 @fixture
@@ -34,10 +36,10 @@ def nexus_psi_delta_file(datadir):
 # pylint: disable=redefined-outer-name
 def test_reading_of_psi_delta_nxs(nexus_psi_delta_file):
     """Psi/delta NeXus file is read w/o errors"""
-    read_psi_delta(nexus_psi_delta_file)
+    elli.read_nexus_psi_delta(nexus_psi_delta_file)
 
 
 # pylint: disable=redefined-outer-name
 def test_reading_and_conv_to_rho(nexus_psi_delta_file):
     """Rho values are read from Psi / Delta file"""
-    read_rho(nexus_psi_delta_file)
+    elli.read_nexus_rho(nexus_psi_delta_file)
